@@ -163,7 +163,7 @@ static const QtNodeType qt_node_types[] = {
   {FOURCC_ctts, "Composition time to sample", 0, qtdemux_dump_ctts},
   {FOURCC_cslg, "Composition Shift Least Greatest", 0, qtdemux_dump_cslg},
   {FOURCC_XiTh, "XiTh", 0},
-  {FOURCC_XdxT, "XdxT", 0},
+  {FOURCC_XdxT, "XdxT", QT_FLAG_CONTAINER},
   {FOURCC_loci, "loci", 0},
   {FOURCC_clsf, "clsf", 0},
   {FOURCC_mfra, "movie fragment random access",
@@ -211,6 +211,9 @@ static const QtNodeType qt_node_types[] = {
   {FOURCC_dvhe, "HEVC-based Dolby Vision codec derived from hev1 ", 0},
   {FOURCC_dvh1, "HEVC-based Dolby Vision codec derived from hvc1 ", 0},
   {FOURCC_dvcC, "HEVC-based Dolby Vision codec configuration container", 0},
+  {FOURCC_vvc1, "VVC codec configuration", 0},
+  {FOURCC_vvi1, "VVC codec configuration", 0},
+  {FOURCC_vvcC, "VVC codec configuration container", 0},
   {FOURCC_tfdt, "Track fragment decode time", 0, qtdemux_dump_tfdt},
   {FOURCC_chap, "Chapter Reference"},
   {FOURCC_btrt, "Bitrate information", 0},
@@ -249,6 +252,10 @@ static const QtNodeType qt_node_types[] = {
   {FOURCC_vttc, "VTTCueBox 14496-30", QT_FLAG_CONTAINER},
   {FOURCC_metx, "XML MetaData Sample Entry", 0},
   {FOURCC_cstb, "Correct Start Time Box", 0},
+  {FOURCC_ipcm, "RAW Integer PCM", 0},
+  {FOURCC_fpcm, "RAW Float PCM", 0},
+  {FOURCC_pcmC, "RAW PCM Configuration Box", 0},
+  {FOURCC_chnl, "Channel Layout Box", 0},
   {0, "unknown", 0,},
 };
 
