@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -31,13 +31,14 @@
 static gboolean
 plugin_init (GstPlugin * plugin)
 {
-  return (gst_element_register (plugin, "gamma", GST_RANK_NONE, GST_TYPE_GAMMA)
-      && gst_element_register (plugin, "videobalance", GST_RANK_NONE,
-          GST_TYPE_VIDEO_BALANCE)
-      && gst_element_register (plugin, "videoflip", GST_RANK_NONE,
-          GST_TYPE_VIDEO_FLIP)
-      && gst_element_register (plugin, "videomedian", GST_RANK_NONE,
-          GST_TYPE_VIDEO_MEDIAN));
+  gboolean ret = FALSE;
+
+  ret |= GST_ELEMENT_REGISTER (gamma, plugin);
+  ret |= GST_ELEMENT_REGISTER (videobalance, plugin);
+  ret |= GST_ELEMENT_REGISTER (videoflip, plugin);
+  ret |= GST_ELEMENT_REGISTER (videomedian, plugin);
+
+  return ret;
 }
 
 GST_PLUGIN_DEFINE (GST_VERSION_MAJOR,
